@@ -21,14 +21,15 @@
 #include "../part/presentationwidget.h"
 #include "../part/sidebar.h"
 #include "../part/toc.h"
-#include "../part/toggleactionmenu.h"
 #include "../settings.h"
 #include "closedialoghelper.h"
 
 #include <KActionCollection>
+#include <KActionMenu>
 #include <KConfigDialog>
 #include <KParts/OpenUrlArguments>
 
+#include <QAbstractItemModelTester>
 #include <QApplication>
 #include <QClipboard>
 #include <QDesktopServices>
@@ -993,6 +994,7 @@ void PartTest::testSaveAs()
     qDebug() << "Open file, add annotation and save both natively and to .okular";
     {
         Okular::Part part(nullptr, {});
+        new QAbstractItemModelTester(part.annotationsModel(), &part);
         part.openDocument(file);
         part.m_document->documentInfo();
 
@@ -1033,6 +1035,7 @@ void PartTest::testSaveAs()
     qDebug() << "Open the .okular, check that the annotation is present and save to native";
     {
         Okular::Part part(nullptr, {});
+        new QAbstractItemModelTester(part.annotationsModel(), &part);
         part.openDocument(archiveSave.fileName());
         part.m_document->documentInfo();
 
@@ -1059,6 +1062,7 @@ void PartTest::testSaveAs()
              << "is there iff we expect it";
     {
         Okular::Part part(nullptr, {});
+        new QAbstractItemModelTester(part.annotationsModel(), &part);
         part.openDocument(nativeDirectSave.fileName());
 
         QCOMPARE(part.m_document->page(0)->annotations().size(), nativelySupportsAnnotations ? 1 : 0);
@@ -1171,6 +1175,7 @@ void PartTest::testSaveAsUndoStackAnnotations()
 
     Okular::Part part(nullptr, {});
     part.openDocument(file);
+    new QAbstractItemModelTester(part.annotationsModel(), &part);
 
     QCOMPARE(part.m_document->canSwapBackingFile(), canSwapBackingFile);
 
@@ -1361,7 +1366,7 @@ void PartTest::testSaveAsUndoStackForms()
         if (ff->id() == 65537) {
             QCOMPARE(ff->type(), FormField::FormText);
             FormFieldText *fft = static_cast<FormFieldText *>(ff);
-            part.m_document->editFormText(0, fft, QStringLiteral("BlaBla"), 6, 0, 0);
+            part.m_document->editFormText(0, fft, QStringLiteral("BlaBla"), 6, 0, 0, QString());
         } else if (ff->id() == 65538) {
             QCOMPARE(ff->type(), FormField::FormButton);
             FormFieldButton *ffb = static_cast<FormFieldButton *>(ff);
@@ -1447,6 +1452,7 @@ void PartTest::test388288()
     Okular::Part part(nullptr, {});
 
     part.openUrl(QUrl::fromLocalFile(QStringLiteral(KDESRCDIR "data/file1.pdf")));
+    new QAbstractItemModelTester(part.annotationsModel(), &part);
 
     part.widget()->show();
     QVERIFY(QTest::qWaitForWindowExposed(part.widget()));
@@ -1624,6 +1630,7 @@ void PartTest::testAnnotWindow()
     QVERIFY(openDocument(&part, QStringLiteral(KDESRCDIR "data/file1.pdf")));
     part.widget()->show();
     part.widget()->resize(800, 600);
+    new QAbstractItemModelTester(part.annotationsModel(), &part);
     QVERIFY(QTest::qWaitForWindowExposed(part.widget()));
 
     part.m_document->setViewportPage(0);
@@ -2306,11 +2313,11 @@ void PartTest::testFieldFormatting()
     QTest::mousePress(usCurrencyWidget, Qt::LeftButton, Qt::NoModifier, QPoint(5, 5));
     QTRY_VERIFY(usCurrencyWidget->hasFocus());
 
-    usCurrencyWidget->setText(QStringLiteral("131.234,567"));
+    usCurrencyWidget->setText(QStringLiteral("131234.567"));
     QTest::mousePress(deCurrencyWidget, Qt::LeftButton, Qt::NoModifier, QPoint(5, 5));
     QTRY_VERIFY(deCurrencyWidget->hasFocus());
     // Check that the internal text still contains it.
-    QCOMPARE(ff_us->text(), QStringLiteral("131.234,567"));
+    QCOMPARE(ff_us->text(), QStringLiteral("131234.567"));
 
     // Just check that the text does not match the internal text.
     // We don't check for a concrete value to keep NaN handling flexible
@@ -2320,7 +2327,7 @@ void PartTest::testFieldFormatting()
     QTest::mousePress(usCurrencyWidget, Qt::LeftButton, Qt::NoModifier, QPoint(5, 5));
     QTRY_VERIFY(usCurrencyWidget->hasFocus());
 
-    usCurrencyWidget->setText(QStringLiteral("1,234.567"));
+    usCurrencyWidget->setText(QStringLiteral("1234.567"));
     QTest::mousePress(deCurrencyWidget, Qt::LeftButton, Qt::NoModifier, QPoint(5, 5));
     QTRY_VERIFY(deCurrencyWidget->hasFocus());
 
@@ -2330,14 +2337,14 @@ void PartTest::testFieldFormatting()
     QCOMPARE(sumCurrencyWidget->text(), QStringLiteral("1.234,57€"));
 
     // Set a text in the de field
-    deCurrencyWidget->setText(QStringLiteral("1,123,234.567"));
+    deCurrencyWidget->setText(QStringLiteral("1123234,567"));
     QTest::mousePress(usCurrencyWidget, Qt::LeftButton, Qt::NoModifier, QPoint(5, 5));
     QTRY_VERIFY(usCurrencyWidget->hasFocus());
 
     QCOMPARE(deCurrencyWidget->text(), QStringLiteral("1.123.234,57 €"));
-    QCOMPARE(ff_de->text(), QStringLiteral("1,123,234.567"));
+    QCOMPARE(ff_de->text(), QStringLiteral("1123234,567"));
     QCOMPARE(sumCurrencyWidget->text(), QStringLiteral("1.124.469,13€"));
-    QCOMPARE(ff_sum->text(), QStringLiteral("1,124,469.1340000000782310962677002"));
+    QCOMPARE(ff_sum->text(), QStringLiteral("1124469.1340000000782310962677002"));
 }
 
 } // namespace Okular
