@@ -22,6 +22,7 @@
 // local includes
 #include "document_p.h"
 #include "observer.h"
+#include "page.h"
 
 using namespace Okular;
 
@@ -398,10 +399,13 @@ QHash<QUrl, QString>::iterator BookmarkManager::Private::bookmarkFind(const QUrl
 
 void BookmarkManager::addBookmark(int page)
 {
-    if (page >= 0 && page < (int)d->document->m_pagesVector.count()) {
-        if (setPageBookmark(page))
-            foreachObserver(notifyPageChanged(page, DocumentObserver::Bookmark));
+    if (isBookmarked(page)) {
+        return;
     }
+
+    DocumentViewport vp;
+    vp.pageNumber = page;
+    addBookmark(vp);
 }
 
 void BookmarkManager::addBookmark(const DocumentViewport &vp)
@@ -453,10 +457,15 @@ bool BookmarkManager::addBookmark(const QUrl &documentUrl, const Okular::Documen
         // name '#p' where p is the page number where the bookmark is located.
         // if there's more than one bookmark per page, give the name '#p-n'
         // where n is the index of this bookmark among the ones of its page.
-        if (count > 0) {
-            newtitle = QStringLiteral("#%1-%2").arg(vp.pageNumber + 1).arg(count);
+        const QString pageLabel = d->document->m_parent->page(vp.pageNumber)->label();
+        newtitle = QStringLiteral("#");
+        if (pageLabel.isNull()) {
+            newtitle += QString::number(vp.pageNumber + 1);
         } else {
-            newtitle = QStringLiteral("#%1").arg(vp.pageNumber + 1);
+            newtitle += pageLabel;
+        }
+        if (count > 0) {
+            newtitle += QStringLiteral("-") + QString::number(count);
         }
     } else {
         newtitle = title;
@@ -651,37 +660,6 @@ void BookmarkManager::setUrl(const QUrl &url)
     }
 }
 
-bool BookmarkManager::setPageBookmark(int page)
-{
-    KBookmarkGroup thebg;
-    QHash<QUrl, QString>::iterator it = d->bookmarkFind(d->url, true, &thebg);
-    Q_ASSERT(it != d->knownFiles.end());
-
-    bool found = false;
-    bool added = false;
-    for (KBookmark bm = thebg.first(); !found && !bm.isNull(); bm = thebg.next(bm)) {
-        if (bm.isSeparator() || bm.isGroup()) {
-            continue;
-        }
-
-        DocumentViewport vp(bm.url().fragment(QUrl::FullyDecoded));
-        if (vp.isValid() && vp.pageNumber == page) {
-            found = true;
-        }
-    }
-    if (!found) {
-        d->urlBookmarks[page]++;
-        DocumentViewport vp;
-        vp.pageNumber = page;
-        QUrl newurl = d->url;
-        newurl.setFragment(vp.toString(), QUrl::DecodedMode);
-        thebg.addBookmark(QLatin1String("#") + QString::number(vp.pageNumber + 1), newurl, QString());
-        added = true;
-        d->manager.emitChanged(thebg);
-    }
-    return added;
-}
-
 bool BookmarkManager::removePageBookmark(int page)
 {
     KBookmarkGroup thebg;
