@@ -592,7 +592,7 @@ public:
      * @param rect The rectangle of the selection.
      * @param color The color of the selection.
      */
-    void setPageTextSelection(int page, RegularAreaRect *rect, const QColor &color);
+    void setPageTextSelection(int page, std::unique_ptr<RegularAreaRect> &&rect, const QColor &color);
 
     /**
      * Returns true if there is an undo command available; otherwise returns false.
@@ -671,23 +671,50 @@ public:
      * Processes the given format @p action on @p fft.
      *
      * @since 1.9
+     * @deprecated use processFormatAction(const Action *, Okular::FormField *).
      */
-    void processFormatAction(const Action *action, Okular::FormFieldText *fft);
+    OKULARCORE_DEPRECATED void processFormatAction(const Action *action, Okular::FormFieldText *fft);
+
+    /**
+     * Processes the given format @p action on a Form Field @p ff.
+     *
+     * @since 24.08
+     */
+    void processFormatAction(const Action *action, Okular::FormField *ff);
 
     /**
      * Processes the given keystroke @p action on @p fft.
      *
      * @since 1.9
+     * @deprecated use processKeystrokeAction(const Action *, Okular::FormField *, const QVariant &, int, int)
      */
-    void processKeystrokeAction(const Action *action, Okular::FormFieldText *fft, const QVariant &newValue);
+    OKULARCORE_DEPRECATED void processKeystrokeAction(const Action *action, Okular::FormFieldText *fft, const QVariant &newValue);
+
+    /**
+     * Processes the given keystroke @p action on @p ff between the two positions @p prevCursorPos and @p prevAnchorPos
+     * @p prevCursorPos and @p prevAnchorPos are used to set the selStart and selEnd event properties.
+     *
+     * @since 24.08
+     */
+    void processKeystrokeAction(const Action *action, Okular::FormField *ff, const QVariant &newValue, int prevCursorPos, int prevAnchorPos);
 
     /**
      * Processes the given keystroke @p action on @p fft.
      * This will set event.willCommit=true
      *
      * @since 22.04
+     * @deprecated use processKeystrokeCommitAction(const Action *, Okular::FormField *, bool &).
      */
-    void processKeystrokeCommitAction(const Action *action, Okular::FormFieldText *fft);
+    OKULARCORE_DEPRECATED void processKeystrokeCommitAction(const Action *action, Okular::FormFieldText *fft);
+
+    /**
+     * Processes the given keystroke @p action on FormField @p ff.
+     * This will set event.willCommit=true.
+     * The return code parameter is set if the value is to be committed.
+     *
+     * @since 24.08
+     */
+    void processKeystrokeCommitAction(const Action *action, Okular::FormField *ff, bool &returnCode);
 
     /**
      * Processes the given focus action on the field.
@@ -700,15 +727,72 @@ public:
      * Processes the given keystroke @p action on @p fft.
      *
      * @since 1.9
+     * @deprecated use processValidateAction(const Action *, Okular::FormField *, bool &).
      */
-    void processValidateAction(const Action *action, Okular::FormFieldText *fft, bool &returnCode);
+    OKULARCORE_DEPRECATED void processValidateAction(const Action *action, Okular::FormFieldText *fft, bool &returnCode);
+
+    /**
+     * Validates the input value in the FormField @p ff and sets the @p returnCode for a given validate @p action.
+     *
+     * @since 24.08
+     */
+    void processValidateAction(const Action *action, Okular::FormField *ff, bool &returnCode);
+
+    /**
+     * A method that executes the relevant keystroke, validate, calculate and format actions on a FormField @p ff.
+     *
+     * @since 24.08
+     */
+    void processKVCFActions(Okular::FormField *ff);
 
     /**
      * Processes the mouse up @p action on @p ff.
      *
+     * @deprecated use @ref processFormMouseScriptAction
      * @since 23.12
      */
-    void processFormMouseUpScripAction(const Action *action, Okular::FormField *ff);
+    OKULARCORE_DEPRECATED void processFormMouseUpScripAction(const Action *action, Okular::FormField *ff);
+
+    enum MouseEventType {
+        FieldMouseDown,  /// < This event is the result of a mouse down on a field.
+        FieldMouseEnter, /// < This event is the result of mouse exiting from a field.
+        FieldMouseExit,  /// < This event is the result of mouse exiting from a field.
+        FieldMouseUp,    /// < This event is the result of a mouse up on a field.
+    };
+
+    /**
+     * Processes the mouse @p action of type @p fieldMouseEventType on @p ff.
+     *
+     * @since 24.12
+     */
+    void processFormMouseScriptAction(const Action *action, Okular::FormField *ff, MouseEventType fieldMouseEventType);
+
+    /**
+     * Describes the additional actions available in the Document.
+     *
+     * @since 24.08
+     */
+    enum DocumentAdditionalActionType {
+        CloseDocument,
+        SaveDocumentStart,
+        SaveDocumentFinish,
+        PrintDocumentStart,
+        PrintDocumentFinish,
+    };
+
+    /**
+     * Processes the given document additional @p action of specified @p type.
+     *
+     * @since 24.08
+     */
+    void processDocumentAction(const Action *action, DocumentAdditionalActionType type);
+
+    /**
+     * Recalculates all the form fields in the document
+     *
+     * @since 24.12
+     */
+    void recalculateForms();
 
     /**
      * Returns a list of the bookmarked.pages
@@ -849,6 +933,11 @@ public:
 
     bool isHistoryClean() const;
 
+    /**
+     * \since 24.12
+     */
+    void clearHistory();
+
     /**
      * Saving capabilities. Their availability varies according to the
      * underlying generator and/or the document type.
@@ -1074,8 +1163,19 @@ public Q_SLOTS:
      * The new text cursor position (@p newCursorPos), previous text cursor position (@p prevCursorPos),
      * and previous cursor anchor position will be restored by the undo / redo commands.
      * @since 0.17 (KDE 4.11)
+     *
+     * @deprecated use editFormText(int pageNumber, Okular::FormFieldText *form, const QString &newContents,
+     *                          int newCursorPos, int prevCursorPos, int prevAnchorPos, const QString &oldContents)
      */
-    void editFormText(int pageNumber, Okular::FormFieldText *form, const QString &newContents, int newCursorPos, int prevCursorPos, int prevAnchorPos);
+    OKULARCORE_DEPRECATED void editFormText(int pageNumber, Okular::FormFieldText *form, const QString &newContents, int newCursorPos, int prevCursorPos, int prevAnchorPos);
+
+    /**
+     * Edit the text contents of the specified @p form on page @p page to be @p newContents where
+     * previous contents are @p oldContents for undo/redo commands. The new text cursor position (@p newCursorPos),
+     * previous text cursor position (@p prevCursorPos), and previous cursor anchor position will be restored by the undo / redo commands.
+     * @since 24.08
+     */
+    void editFormText(int pageNumber, Okular::FormFieldText *form, const QString &newContents, int newCursorPos, int prevCursorPos, int prevAnchorPos, const QString &oldContents);
 
     /**
      * Edit the selected list entries in @p form on page @p page to be @p newChoices.
@@ -1581,6 +1681,18 @@ public:
     /// @since 23.08
     void setBackgroundImagePath(const QString &path);
 
+    /// @since 25.04
+    double fontSize() const;
+
+    /// @since 25.04
+    void setFontSize(double fontSize);
+
+    /// @since 25.04
+    double leftFontSize() const;
+
+    /// @since 25.04
+    void setLeftFontSize(double fontSize);
+
 private:
     NewSignatureDataPrivate *const d;
 };
