@@ -363,6 +363,16 @@ const QList<EmbeddedFile *> *Generator::embeddedFiles() const
     return nullptr;
 }
 
+Generator::PageLayout Generator::defaultPageLayout() const
+{
+    return NoLayout;
+}
+
+bool Generator::defaultPageContinuous() const
+{
+    return false;
+}
+
 Generator::PageSizeMetric Generator::pagesSizeMetric() const
 {
     return None;
@@ -391,8 +401,9 @@ Document::PrintError Generator::print(QPrinter &)
     return Document::UnknownPrintError;
 }
 
-void Generator::opaqueAction(const BackendOpaqueAction * /*action*/)
+BackendOpaqueAction::OpaqueActionResult Generator::opaqueAction(const BackendOpaqueAction * /*action*/)
 {
+    return BackendOpaqueAction::DoNothing;
 }
 
 void Generator::freeOpaqueActionContents(const BackendOpaqueAction & /*action*/)
