@@ -7,7 +7,6 @@
 #include "converter.h"
 
 #include <QAbstractTextDocumentLayout>
-#include <QApplication> // Because of the HACK
 #include <QFileInfo>
 #include <QRegularExpression>
 #include <QTextDocument>
@@ -195,13 +194,6 @@ QTextDocument *Converter::convert(const QString &fileName)
     QVector<Okular::MovieAnnotation *> movieAnnots;
     QVector<Okular::SoundAction *> soundActions;
 
-    // HACK BEGIN Get the links without CSS to be blue
-    //            Remove if Qt ever gets fixed and the code in textdocumentgenerator.cpp works
-    const QPalette orig = qApp->palette();
-    QPalette p = orig;
-    p.setColor(QPalette::Link, Qt::blue);
-    // HACK END
-
     const QSize videoSize(320, 240);
     do {
         if (!epub_it_get_curr(it)) {
@@ -299,10 +291,6 @@ QTextDocument *Converter::convert(const QString &fileName)
             htmlContent = dom.toString();
         }
 
-        // HACK BEGIN
-        qApp->setPalette(p);
-        // HACK END
-
         QTextBlock before;
         if (firstPage) {
             mTextDocument->setHtml(htmlContent);
@@ -312,9 +300,6 @@ QTextDocument *Converter::convert(const QString &fileName)
             before = _cursor->block();
             _cursor->insertHtml(htmlContent);
         }
-        // HACK BEGIN
-        qApp->setPalette(orig);
-        // HACK END
 
         QTextCursor csr(before); // a temporary cursor pointing at the begin of the last inserted block
         int index = 0;
