@@ -447,10 +447,17 @@ static Okular::SigningResult popperToOkular(Poppler::SignatureAnnotation::Signin
         return Okular::GenericSigningError;
 #if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(24, 12, 0)
     case Poppler::SignatureAnnotation::InternalError:
+        return Okular::InternalSigningError;
     case Poppler::SignatureAnnotation::KeyMissing:
+        return Okular::KeyMissing;
     case Poppler::SignatureAnnotation::WriteFailed:
+        return Okular::SignatureWriteFailed;
     case Poppler::SignatureAnnotation::UserCancelled:
-        return Okular::GenericSigningError;
+        return Okular::UserCancelled;
+#endif
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(25, 02, 90)
+    case Poppler::SignatureAnnotation::BadPassphrase:
+        return Okular::UserCancelled;
 #endif
     }
     return Okular::GenericSigningError;
@@ -504,6 +511,8 @@ static std::unique_ptr<Poppler::Annotation> createPopplerAnnotationFromOkularAnn
     pSignatureAnnotation->setLeftText(oSignatureAnnotation->leftText());
     pSignatureAnnotation->setText(oSignatureAnnotation->text());
     pSignatureAnnotation->setFieldPartialName(oSignatureAnnotation->fieldPartialName());
+    pSignatureAnnotation->setFontSize(oSignatureAnnotation->fontSize());
+    pSignatureAnnotation->setLeftFontSize(oSignatureAnnotation->leftFontSize());
 
     if (!oSignatureAnnotation->imagePath().isEmpty()) {
         QSize imageSize = calculateImagePixelSize(oSignatureAnnotation->page(), oSignatureAnnotation->boundingRectangle(), pdfdoc);
