@@ -32,6 +32,7 @@
 #include <QTextStream>
 #include <QTimeZone>
 #include <QTimer>
+#include <QXmlStreamReader>
 
 #include <KAboutData>
 #include <KConfigDialog>
@@ -362,7 +363,7 @@ QPair<Okular::Movie *, Okular::EmbeddedFile *> createMovieFromPopplerRichMedia(c
     return qMakePair(movie, pdfEmbeddedFile);
 }
 
-static Okular::DocumentAction::DocumentActionType popplerToOkular(Poppler::LinkAction::ActionType pat)
+static std::optional<Okular::DocumentAction::DocumentActionType> popplerToOkular(Poppler::LinkAction::ActionType pat)
 {
     switch (pat) {
     case Poppler::LinkAction::PageFirst:
@@ -398,10 +399,7 @@ static Okular::DocumentAction::DocumentActionType popplerToOkular(Poppler::LinkA
     }
 
     qWarning() << "Unsupported Poppler::LinkAction::ActionType" << pat;
-    // TODO When we can use C++17 make this function return an optional
-    //      for now it's not super important since at the time of writing
-    //      okular DocumentAction supports all that poppler ActionType supports
-    return Okular::DocumentAction::PageFirst;
+    return {};
 }
 
 // helper for using std::visit to get a dependent false for static_asserts
@@ -473,7 +471,10 @@ Okular::Action *createLinkFromPopplerLink(std::variant<const Poppler::Link *, st
 
     case Poppler::Link::Action: {
         auto popplerLinkAction = static_cast<const Poppler::LinkAction *>(rawPopplerLink);
-        link = new Okular::DocumentAction(popplerToOkular(popplerLinkAction->actionType()));
+        const auto okularLinkActionType = popplerToOkular(popplerLinkAction->actionType());
+        if (okularLinkActionType) {
+            link = new Okular::DocumentAction(okularLinkActionType.value());
+        }
         break;
     }
 
@@ -668,6 +669,7 @@ PDFGenerator::PDFGenerator(QObject *parent, const QVariantList &args)
     , pdfdoc(nullptr)
     , docSynopsisDirty(true)
     , xrefReconstructed(false)
+    , hasVisibleOverprint(false)
     , docEmbeddedFilesDirty(true)
     , nextFontPage(0)
     , annotProxy(nullptr)
@@ -701,6 +703,9 @@ PDFGenerator::PDFGenerator(QObject *parent, const QVariantList &args)
         Poppler::setActiveCryptoSignBackend(activeBackend.value());
     }
 #endif
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(25, 02, 90)
+    Poppler::setPgpSignaturesAllowed(PDFSettings::enablePgp());
+#endif
 }
 
 PDFGenerator::~PDFGenerator()
@@ -771,6 +776,16 @@ Okular::Document::OpenResult PDFGenerator::init(QVector<Okular::Page *> &pagesVe
         pdfdoc->setXRefReconstructedCallback(cb);
     }
 
+    hasVisibleOverprint = false;
+    QXmlStreamReader xml(pdfdoc->metadata());
+    while (!xml.atEnd()) {
+        xml.readNext();
+        if (xml.isStartElement() && xml.name() == QStringLiteral("HasVisibleOverprint")) {
+            xml.readNext();
+            hasVisibleOverprint = xml.text().toString().toLower() == QStringLiteral("true");
+        }
+    }
+
     // build Pages (currentPage was set -1 by deletePages)
     int pageCount = pdfdoc->numPages();
     if (pageCount < 0) {
@@ -1161,29 +1176,21 @@ const QList<Okular::EmbeddedFile *> *PDFGenerator::embeddedFiles() const
 PDFGenerator::PageLayout PDFGenerator::defaultPageLayout() const
 {
     Poppler::Document::PageLayout defaultValue = pdfdoc->pageLayout();
-    PDFGenerator::PageLayout retValue;
 
     switch (defaultValue) {
     case Poppler::Document::OneColumn:
     case Poppler::Document::SinglePage:
-        retValue = PDFGenerator::SinglePage;
-        break;
-
+        return PDFGenerator::SinglePage;
     case Poppler::Document::TwoColumnLeft:
     case Poppler::Document::TwoPageLeft:
-        retValue = PDFGenerator::TwoPageLeft;
-        break;
-
+        return PDFGenerator::TwoPageLeft;
     case Poppler::Document::TwoPageRight:
     case Poppler::Document::TwoColumnRight:
-        retValue = PDFGenerator::TwoPageRight;
-        break;
-
+        return PDFGenerator::TwoPageRight;
     case Poppler::Document::NoLayout:
-        retValue = PDFGenerator::NoLayout;
-        break;
+        return PDFGenerator::NoLayout;
     }
-    return retValue;
+    return PDFGenerator::NoLayout;
 }
 
 bool PDFGenerator::defaultPageContinuous() const
@@ -1490,6 +1497,8 @@ void PDFGenerator::okularToPoppler(const Okular::NewSignatureData &oData, Popple
     const QString datetime = QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd hh:mm:ss t"));
     pData->setSignatureText(i18n("Signed by: %1\n\nDate: %2", oData.certSubjectCommonName(), datetime));
     pData->setSignatureLeftText(oData.certSubjectCommonName());
+    pData->setFontSize(oData.fontSize());
+    pData->setLeftFontSize(oData.leftFontSize());
     const Okular::NormalizedRect bRect = oData.boundingRectangle();
     pData->setBoundingRectangle({bRect.left, bRect.top, bRect.width(), bRect.height()});
     pData->setFontColor(Qt::black);
@@ -1513,7 +1522,8 @@ Okular::Document::PrintError PDFGenerator::print(QPrinter &printer)
         scaleMode = pdfOptionsPage->scaleMode();
     }
 
-    const auto overprintPreviewEnabled = PDFSettings::overprintPreviewEnabled();
+    const auto overprintSetting = PDFSettings::overprintPreviewEnabled();
+    const auto overprintPreviewEnabled = overprintSetting == PDFSettings::EnumOverprintPreviewEnabled::Always || (overprintSetting == PDFSettings::EnumOverprintPreviewEnabled::Automatic && hasVisibleOverprint);
 
 #ifdef Q_OS_WIN
     // Windows can only print by rasterization, because that is
@@ -1766,7 +1776,8 @@ bool PDFGenerator::setDocumentRenderHints()
     // load thin line mode
     const int thinLineMode = PDFSettings::enhanceThinLines();
 #if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(23, 07, 0)
-    const bool enableOverprintPreview = PDFSettings::overprintPreviewEnabled();
+    const auto overprintSetting = PDFSettings::overprintPreviewEnabled();
+    const auto enableOverprintPreview = overprintSetting == PDFSettings::EnumOverprintPreviewEnabled::Always || (overprintSetting == PDFSettings::EnumOverprintPreviewEnabled::Automatic && hasVisibleOverprint);
 #endif
     const bool enableThinLineSolid = thinLineMode == PDFSettings::EnumEnhanceThinLines::Solid;
     const bool enableShapeLineSolid = thinLineMode == PDFSettings::EnumEnhanceThinLines::Shape;
