@@ -73,9 +73,9 @@ static QColor hexToRgba(const QByteArray &name)
     return QColor(r, g, b, a);
 }
 
-static QRectF stringToRectF(const QString &data)
+static QRectF stringToRectF(QStringView data)
 {
-    QStringList numbers = data.split(QLatin1Char(','));
+    const QList<QStringView> numbers = data.split(QLatin1Char(','));
     QPointF origin(numbers.at(0).toDouble(), numbers.at(1).toDouble());
     QSizeF size(numbers.at(2).toDouble(), numbers.at(3).toDouble());
     return QRectF(origin, size);
@@ -686,7 +686,7 @@ static QString unicodeString(const QString &raw)
     return ret;
 }
 
-void XpsPage::processGlyph(QPainter *painter, XpsRenderNode &node)
+void XpsPage::processGlyph(QPainter *painter, const XpsRenderNode &node)
 {
     // TODO Currently ignored attributes: CaretStops, DeviceFontName, IsSideways, OpacityMask, Name, FixedPage.NavigateURI, xml:lang, x:key
     // TODO Indices is only partially implemented
@@ -864,8 +864,8 @@ void XpsPage::processImageBrush(XpsRenderNode &node)
     QString att;
     QBrush brush;
 
-    QRectF viewport = stringToRectF(node.attributes.value(QStringLiteral("Viewport")).toString());
-    QRectF viewbox = stringToRectF(node.attributes.value(QStringLiteral("Viewbox")).toString());
+    QRectF viewport = stringToRectF(node.attributes.value(QStringLiteral("Viewport")));
+    QRectF viewbox = stringToRectF(node.attributes.value(QStringLiteral("Viewbox")));
     QImage image = loadImageFromFile(node.attributes.value(QStringLiteral("ImageSource")).toString());
 
     // Matrix which can transform [0, 0, 1, 1] rectangle to given viewbox
@@ -893,7 +893,7 @@ void XpsPage::processImageBrush(XpsRenderNode &node)
     node.data = QVariant::fromValue(brush);
 }
 
-void XpsPage::processPath(QPainter *painter, XpsRenderNode &node)
+void XpsPage::processPath(QPainter *painter, const XpsRenderNode &node)
 {
     // TODO Ignored attributes: Clip, OpacityMask, StrokeEndLineCap, StorkeStartLineCap, Name, FixedPage.NavigateURI, xml:lang, x:key, AutomationProperties.Name, AutomationProperties.HelpText, SnapsToDevicePixels
     // TODO Ignored child elements: RenderTransform, Clip, OpacityMask
@@ -1172,7 +1172,7 @@ void XpsPage::processPathFigure(XpsRenderNode &node)
     }
 }
 
-void XpsPage::processStartElement(QPainter *painter, XpsRenderNode &node)
+void XpsPage::processStartElement(QPainter *painter, const XpsRenderNode &node)
 {
     if (node.name == QLatin1String("Canvas")) {
         painter->save();
@@ -1577,9 +1577,9 @@ Okular::TextPage *XpsPage::textPage()
                 for (int i = 0; i < text.length(); i++) {
                     const int width = metrics.horizontalAdvance(text, i + 1);
 
-                    Okular::NormalizedRect *rect =
-                        new Okular::NormalizedRect((origin.x() + lastWidth) / m_pageSize.width(), (origin.y() - metrics.height()) / m_pageSize.height(), (origin.x() + width) / m_pageSize.width(), origin.y() / m_pageSize.height());
-                    rect->transform(matrix);
+                    Okular::NormalizedRect rect =
+                        Okular::NormalizedRect((origin.x() + lastWidth) / m_pageSize.width(), (origin.y() - metrics.height()) / m_pageSize.height(), (origin.x() + width) / m_pageSize.width(), origin.y() / m_pageSize.height());
+                    rect.transform(matrix);
                     textPage->append(text.mid(i, 1), rect);
 
                     lastWidth = width;
@@ -1982,7 +1982,7 @@ bool XpsGenerator::loadDocument(const QString &fileName, QVector<Okular::Page *>
     int pagesVectorOffset = 0;
 
     for (int docNum = 0; docNum < m_xpsFile->numDocuments(); ++docNum) {
-        XpsDocument *doc = m_xpsFile->document(docNum);
+        const XpsDocument *doc = m_xpsFile->document(docNum);
         for (int pageNum = 0; pageNum < doc->numPages(); ++pageNum) {
             QSizeF pageSize = doc->page(pageNum)->size();
             pagesVector[pagesVectorOffset] = new Okular::Page(pagesVectorOffset, pageSize.width(), pageSize.height(), Okular::Rotation0);
