@@ -77,15 +77,16 @@ void FormWidgetsController::signalAction(Okular::Action *a)
     Q_EMIT action(a);
 }
 
-void FormWidgetsController::signalMouseUpAction(Okular::Action *action, Okular::FormField *form)
+void FormWidgetsController::signalMouseAction(Okular::Action *action, Okular::FormField *form, Okular::Document::MouseEventType fieldMouseEventType)
 {
-    Q_EMIT mouseUpAction(action, form);
+    Q_EMIT mouseAction(action, form, fieldMouseEventType);
 }
 
 void FormWidgetsController::processScriptAction(Okular::Action *a, Okular::FormField *field, Okular::Annotation::AdditionalActionType type)
 {
-    // If it's not a Action Script or if the field is not a FormText, handle it normally
-    if (a->actionType() != Okular::Action::Script || field->type() != Okular::FormField::FormText) {
+    // If it's not a Action Script or if the field is neither a FormText nor a combobox FormChoice, handle it normally
+    if (a->actionType() != Okular::Action::Script ||
+        (field->type() != Okular::FormField::FormText && !(field->type() == Okular::FormField::FormChoice && (dynamic_cast<Okular::FormFieldChoice *>(field)->choiceType() == Okular::FormFieldChoice::ComboBox)))) {
         Q_EMIT action(a);
         return;
     }
@@ -568,6 +569,10 @@ bool FormLineEdit::event(QEvent *e)
 {
     if (e->type() == QEvent::KeyPress) {
         QKeyEvent *keyEvent = static_cast<QKeyEvent *>(e);
+        if (keyEvent->key() == Qt::Key_Enter || keyEvent->key() == Qt::Key_Return) {
+            m_controller->document()->processKVCFActions(m_ff);
+            return true;
+        }
         if (keyEvent == QKeySequence::Undo) {
             Q_EMIT m_controller->requestUndo();
             return true;
@@ -683,8 +688,8 @@ void FormLineEdit::slotHandleTextChangedByUndoRedo(int pageNumber, Okular::FormF
     m_prevAnchorPos = anchorPos;
 
     // If the contents of the box have already lost focus, we need to run all the keystroke, validation, formatting scripts again.
-    if (!hasFocus()) { // if lineEdit already had focus, undoing/redoing was still retain the focus and these scripts would execute when focus is lost.
-        // TODO handle the keystroke, validate, calculate, format events here.
+    if (!hasFocus()) { // if lineEdit already had focus, undoing/redoing will still retain the focus and these scripts would execute when focus is lost or enter key is pressed.
+        m_controller->document()->processKVCFActions(textForm);
     }
 }
 
@@ -743,9 +748,22 @@ bool TextAreaEdit::event(QEvent *e)
             setText(fft->text());
         }
         m_editing = true;
+
+        QFocusEvent *focusEvent = static_cast<QFocusEvent *>(e);
+        if (focusEvent->reason() != Qt::ActiveWindowFocusReason) {
+            if (const Okular::Action *action = m_ff->additionalAction(Okular::Annotation::FocusIn)) {
+                m_controller->document()->processFocusAction(action, fft);
+            }
+        }
+        setFocus();
     } else if (e->type() == QEvent::FocusOut) {
         m_editing = false;
 
+        QFocusEvent *focusEvent = static_cast<QFocusEvent *>(e);
+        if (focusEvent->reason() == Qt::OtherFocusReason || focusEvent->reason() == Qt::ActiveWindowFocusReason) {
+            return true;
+        }
+
         m_controller->document()->processKVCFActions(m_ff);
 
         if (const Okular::Action *action = m_ff->additionalAction(Okular::Annotation::FocusOut)) {
@@ -803,8 +821,8 @@ void TextAreaEdit::slotHandleTextChangedByUndoRedo(int pageNumber, Okular::FormF
     setTextCursor(c);
 
     // If the contents of the box have already lost focus, we need to run all the keystroke, validation, formatting scripts again.
-    if (!hasFocus()) { // if lineEdit already had focus, undoing/redoing was still retain the focus and these scripts would execute when focus is lost.
-        // TODO handle the keystroke, validate, calculate, format events here.
+    if (!hasFocus()) { // if lineEdit already had focus, undoing/redoing will still retain the focus and these scripts would execute when focus is lost or enter key is pressed.
+        m_controller->document()->processKVCFActions(textForm);
     }
 }
 
@@ -1065,6 +1083,7 @@ ComboEdit::ComboEdit(Okular::FormFieldChoice *choice, PageView *pageView)
     connect(this, &QComboBox::editTextChanged, this, &ComboEdit::slotValueChanged);
     connect(lineEdit(), &QLineEdit::cursorPositionChanged, this, &ComboEdit::slotValueChanged);
 
+    m_editing = false;
     setVisible(choice->isVisible());
     setCursor(Qt::ArrowCursor);
     m_prevCursorPos = lineEdit()->cursorPosition();
@@ -1090,10 +1109,19 @@ void ComboEdit::slotValueChanged()
         prevText = form->choices().at(form->currentChoices().constFirst());
     }
 
-    int cursorPos = lineEdit()->cursorPosition();
+    int cursorPos;
     if (text != prevText) {
-        Q_EMIT m_controller->formComboChangedByWidget(pageItem()->pageNumber(), form, currentText(), cursorPos, m_prevCursorPos, m_prevAnchorPos);
+        if (form->additionalAction(Okular::FormField::FieldModified) && m_editing && !form->isReadOnly()) {
+            m_controller->document()->processKeystrokeAction(form->additionalAction(Okular::FormField::FieldModified), form, lineEdit()->text(), m_prevCursorPos, m_prevAnchorPos);
+        }
+        cursorPos = lineEdit()->cursorPosition();
+        if (text == lineEdit()->text()) {
+            Q_EMIT m_controller->formComboChangedByWidget(pageItem()->pageNumber(), form, currentText(), cursorPos, m_prevCursorPos, m_prevAnchorPos);
+        }
+    } else {
+        cursorPos = lineEdit()->cursorPosition();
     }
+
     m_prevCursorPos = cursorPos;
     m_prevAnchorPos = cursorPos;
     if (lineEdit()->hasSelectedText()) {
@@ -1169,6 +1197,10 @@ bool ComboEdit::event(QEvent *e)
 {
     if (e->type() == QEvent::KeyPress) {
         QKeyEvent *keyEvent = static_cast<QKeyEvent *>(e);
+        if (keyEvent->key() == Qt::Key_Enter || keyEvent->key() == Qt::Key_Return) {
+            m_controller->document()->processKVCFActions(m_ff);
+            return true;
+        }
         if (keyEvent == QKeySequence::Undo) {
             Q_EMIT m_controller->requestUndo();
             return true;
@@ -1176,6 +1208,40 @@ bool ComboEdit::event(QEvent *e)
             Q_EMIT m_controller->requestRedo();
             return true;
         }
+    } else if (e->type() == QEvent::FocusIn) {
+        const auto ffc = static_cast<Okular::FormFieldChoice *>(m_ff);
+
+        QString prevText;
+        if (ffc->currentChoices().isEmpty()) {
+            prevText = ffc->editChoice();
+        } else {
+            prevText = ffc->choices().at(ffc->currentChoices().constFirst());
+        }
+        if (lineEdit()->text() != prevText) {
+            lineEdit()->setText(prevText);
+        }
+        QFocusEvent *focusEvent = static_cast<QFocusEvent *>(e);
+        if (focusEvent->reason() != Qt::ActiveWindowFocusReason) {
+            if (const Okular::Action *action = m_ff->additionalAction(Okular::Annotation::FocusIn)) {
+                m_controller->document()->processFocusAction(action, m_ff);
+            }
+        }
+        setFocus();
+        m_editing = true;
+    } else if (e->type() == QEvent::FocusOut) {
+        m_editing = false;
+
+        // Don't worry about focus events from other sources than the user FocusEvent to edit the field
+        QFocusEvent *focusEvent = static_cast<QFocusEvent *>(e);
+        if (focusEvent->reason() == Qt::OtherFocusReason || focusEvent->reason() == Qt::ActiveWindowFocusReason) {
+            return true;
+        }
+
+        m_controller->document()->processKVCFActions(m_ff);
+
+        if (const Okular::Action *action = m_ff->additionalAction(Okular::Annotation::FocusOut)) {
+            m_controller->document()->processFocusAction(action, m_ff);
+        }
     }
     return QComboBox::event(e);
 }
@@ -1348,7 +1414,7 @@ void SignatureEdit::signUnsignedSignature()
     {                                                                                                                                                                                                                                          \
         Okular::Action *act = m_ff->additionalAction(Okular::Annotation::MousePressed);                                                                                                                                                        \
         if (act) {                                                                                                                                                                                                                             \
-            m_controller->signalAction(act);                                                                                                                                                                                                   \
+            m_controller->signalMouseAction(act, m_ff, Okular::Document::FieldMouseDown);                                                                                                                                                      \
         }                                                                                                                                                                                                                                      \
         BaseClass::mousePressEvent(event);                                                                                                                                                                                                     \
     }                                                                                                                                                                                                                                          \
@@ -1360,9 +1426,9 @@ void SignatureEdit::signUnsignedSignature()
         }                                                                                                                                                                                                                                      \
         Okular::Action *act = m_ff->activationAction();                                                                                                                                                                                        \
         if (act && !qobject_cast<CheckBoxEdit *>(this)) {                                                                                                                                                                                      \
-            m_controller->signalMouseUpAction(act, m_ff);                                                                                                                                                                                      \
+            m_controller->signalMouseAction(act, m_ff, Okular::Document::FieldMouseUp);                                                                                                                                                        \
         } else if ((act = m_ff->additionalAction(Okular::Annotation::MouseReleased))) {                                                                                                                                                        \
-            m_controller->signalMouseUpAction(act, m_ff);                                                                                                                                                                                      \
+            m_controller->signalMouseAction(act, m_ff, Okular::Document::FieldMouseUp);                                                                                                                                                        \
         }                                                                                                                                                                                                                                      \
         BaseClass::mouseReleaseEvent(event);                                                                                                                                                                                                   \
     }                                                                                                                                                                                                                                          \
@@ -1386,7 +1452,7 @@ void SignatureEdit::signUnsignedSignature()
     {                                                                                                                                                                                                                                          \
         Okular::Action *act = m_ff->additionalAction(Okular::Annotation::CursorLeaving);                                                                                                                                                       \
         if (act) {                                                                                                                                                                                                                             \
-            m_controller->signalAction(act);                                                                                                                                                                                                   \
+            m_controller->signalMouseAction(act, m_ff, Okular::Document::FieldMouseExit);                                                                                                                                                      \
         }                                                                                                                                                                                                                                      \
         BaseClass::leaveEvent(event);                                                                                                                                                                                                          \
     }                                                                                                                                                                                                                                          \
@@ -1394,7 +1460,7 @@ void SignatureEdit::signUnsignedSignature()
     {                                                                                                                                                                                                                                          \
         Okular::Action *act = m_ff->additionalAction(Okular::Annotation::CursorEntering);                                                                                                                                                      \
         if (act) {                                                                                                                                                                                                                             \
-            m_controller->signalAction(act);                                                                                                                                                                                                   \
+            m_controller->signalMouseAction(act, m_ff, Okular::Document::FieldMouseEnter);                                                                                                                                                     \
         }                                                                                                                                                                                                                                      \
         BaseClass::enterEvent(event);                                                                                                                                                                                                          \
     }
