@@ -166,53 +166,4 @@ private:
     void treeViewDeleted(QObject *);
 };
 
-/**
- * Creates a widget featuring a KTreeViewSearchLine, a label with the text
- * "Search" and a button to clear the search.
- */
-class KTreeViewSearchLineWidget : public QWidget
-{
-    Q_OBJECT
-
-public:
-    /**
-     * Creates a KTreeViewSearchLineWidget for \a treeView with \a parent as the
-     * parent.
-     */
-    explicit KTreeViewSearchLineWidget(QWidget *parent = nullptr, QTreeView *treeView = nullptr);
-
-    /**
-     * Destroys the KTreeViewSearchLineWidget
-     */
-    ~KTreeViewSearchLineWidget() override;
-
-    /**
-     * Returns a pointer to the search line.
-     */
-    KTreeViewSearchLine *searchLine() const;
-
-protected Q_SLOTS:
-    /**
-     * Creates the widgets inside of the widget.  This is called from the
-     * constructor via a single shot timer so that it is guaranteed to run
-     * after construction is complete.  This makes it suitable for overriding in
-     * subclasses.
-     */
-    virtual void createWidgets();
-
-protected:
-    /**
-     * Creates the search line.  This can be useful to reimplement in cases where
-     * a KTreeViewSearchLine subclass is used.
-     *
-     * It is const because it is be called from searchLine(), which to the user
-     * doesn't conceptually alter the widget.
-     */
-    virtual KTreeViewSearchLine *createSearchLine(QTreeView *treeView) const;
-
-private:
-    class Private;
-    Private *const d;
-};
-
 #endif
