@@ -359,14 +359,14 @@ void ProgressWidget::slotGotoNormalizedPage(float index)
 void ProgressWidget::mouseMoveEvent(QMouseEvent *e)
 {
     if ((QApplication::mouseButtons() & Qt::LeftButton) && width() > 0) {
-        slotGotoNormalizedPage((float)(QApplication::isRightToLeft() ? width() - e->x() : e->x()) / (float)width());
+        slotGotoNormalizedPage((float)(QApplication::isRightToLeft() ? width() - e->position().x() : e->position().x()) / (float)width());
     }
 }
 
 void ProgressWidget::mousePressEvent(QMouseEvent *e)
 {
     if (e->button() == Qt::LeftButton && width() > 0) {
-        slotGotoNormalizedPage((float)(QApplication::isRightToLeft() ? width() - e->x() : e->x()) / (float)width());
+        slotGotoNormalizedPage((float)(QApplication::isRightToLeft() ? width() - e->position().x() : e->position().x()) / (float)width());
     }
 }
 
@@ -483,8 +483,7 @@ PagesEdit::PagesEdit(MiniBar *parent)
     // send a focus out event
     QFocusEvent fe(QEvent::FocusOut);
     QApplication::sendEvent(this, &fe);
-
-    connect(qApp, &QGuiApplication::paletteChanged, this, &PagesEdit::updatePalette);
+    qApp->installEventFilter(this);
 }
 
 void PagesEdit::setText(const QString &newText)
@@ -528,6 +527,14 @@ void PagesEdit::updatePalette()
     setPalette(pal);
 }
 
+bool PagesEdit::eventFilter(QObject *watched, QEvent *e)
+{
+    if (watched == qApp && e->type() == QEvent::ApplicationPaletteChange) {
+        updatePalette();
+    }
+    return KLineEdit::eventFilter(watched, e);
+}
+
 void PagesEdit::focusInEvent(QFocusEvent *e)
 {
     // select all text
