@@ -20,6 +20,7 @@
 
 #include "config-okular.h"
 #include "core/area.h"
+#include "core/document.h"
 #include "core/observer.h"
 #include "core/view.h"
 #include "pageviewutils.h"
@@ -27,6 +28,8 @@
 #include <QList>
 #include <QVector>
 
+#include "signaturepartutils.h"
+
 class QMenu;
 class QMimeData;
 class KActionCollection;
@@ -41,6 +44,7 @@ class FormFieldSignature;
 class Annotation;
 class MovieAction;
 class RenditionAction;
+class SignatureAnnotation;
 }
 
 class PageViewPrivate;
@@ -65,6 +69,12 @@ public:
 
     enum ClearMode { ClearAllSelection, ClearOnlyDividers };
 
+    enum FinishSigningResult {
+        Success,
+        Failed,
+        Cancelled,
+    };
+
     // create actions that interact with this widget
     void setupBaseActions(KActionCollection *ac);
     void setupViewerActions(KActionCollection *ac);
@@ -121,6 +131,8 @@ public:
 
     Okular::Document *document() const;
 
+    void startSigning(Okular::SignatureAnnotation *signatureAnnotation);
+
 public Q_SLOTS:
     void copyTextSelection() const;
     void selectAll();
@@ -131,10 +143,13 @@ public Q_SLOTS:
     void slotSelectPage();
 
     void slotAction(Okular::Action *action);
-    void slotMouseUpAction(Okular::Action *action, Okular::FormField *form);
+    void slotMouseAction(Okular::Action *action, Okular::FormField *form, Okular::Document::MouseEventType fieldMouseEventType);
     void slotFormChanged(int pageNumber);
 
     void externalKeyPressEvent(QKeyEvent *e);
+#if HAVE_NEW_SIGNATURE_API
+    PageView::FinishSigningResult finishSigning();
+#endif
 
 Q_SIGNALS:
     void rightClick(const Okular::Page *, const QPoint);
@@ -149,6 +164,8 @@ Q_SIGNALS:
      * \param pageNumber page to show (1-indexed)
      */
     void requestOpenNewlySignedFile(const QString &filePath, int pageNumber);
+    void signingStarted();
+    void signingFinished();
 
 protected:
     bool event(QEvent *event) override;
@@ -304,6 +321,7 @@ private Q_SLOTS:
     void slotRefreshPage();
 #if HAVE_SPEECH
     void slotSpeakDocument();
+    void slotSpeakFromCurrentPage();
     void slotSpeakCurrentPage();
     void slotStopSpeaks();
     void slotPauseResumeSpeech();
